==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/utility/units_and_measurements/measurements/_1684.py <==
"""ElectricalResistivity"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_ELECTRICAL_RESISTIVITY = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "ElectricalResistivity"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ElectricalResistivity")
    CastSelf = TypeVar(
        "CastSelf", bound="ElectricalResistivity._Cast_ElectricalResistivity"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ElectricalResistivity",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ElectricalResistivity:
    """Special nested class for casting ElectricalResistivity to subclasses."""

    __parent__: "ElectricalResistivity"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def electrical_resistivity(self: "CastSelf") -> "ElectricalResistivity":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ElectricalResistivity(_1655.MeasurementBase):
    """ElectricalResistivity

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ELECTRICAL_RESISTIVITY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ElectricalResistivity":
        """Cast to another type.

        Returns:
            _Cast_ElectricalResistivity
        """
        return _Cast_ElectricalResistivity(self)

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/utility/units_and_measurements/measurements/_1684.py <==
"""Density"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_DENSITY = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Density"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Density")
    CastSelf = TypeVar("CastSelf", bound="Density._Cast_Density")


__docformat__ = "restructuredtext en"
__all__ = ("Density",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Density:
    """Special nested class for casting Density to subclasses."""

    __parent__: "Density"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def density(self: "CastSelf") -> "Density":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Density(_1657.MeasurementBase):
    """Density

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DENSITY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Density":
        """Cast to another type.

        Returns:
            _Cast_Density
        """
        return _Cast_Density(self)
